@@ -1,7 +1,9 @@
+# frozen_string_literal: true
+
 module Riemann
   class Message
     include Beefcake::Message
-    
+
     optional :ok, :bool, 2
     optional :error, :string, 3
     repeated :states, State, 4
@@ -9,9 +11,8 @@ module Riemann
     repeated :events, Event, 6
 
     def encode_with_length
-      buffer = ''
-      encoded = encode buffer
-      "#{[encoded.length].pack('N')}#{encoded}"
+      encoded_string = encode.to_s
+      [encoded_string.length].pack('N') << encoded_string
     end
-  end 
+  end
 end
